# PyMetrology

- Quick Link to Production Branch
- Quick Link to Devel Branch

# Overview

## What is PyMetrology ?

Note: source code was extracted from PySpice, in development ...

PyMetrology is a Python module which implements a unit framework.

## Where is the Documentation ?

The documentation is available on the PyMetrology Home Page.

## What are the main features ?

- to be completed

## How to install it ?

Look at the installation section in the documentation.

# Credits

Authors: Fabrice Salvaire

# News

## V0 2017-10-01

Started project